# -*- coding: utf-8 -*-
"""Package configuration."""

ERROR_404 = u'<p>The listing does not exist in the MLS.</p>'

ERROR_503 = u'<p>The MLS is currently not available. If the error persists, ' \
            u'please contact <a href="mailto:support@propertyshelf.com">' \
            u'support@propertyshelf.com</a>.</p><p>Please also double check ' \
            u'your <a href="%(portal_url)s/@@mls-controlpanel">MLS settings' \
            u'</a>.</p>'
